@@ -29,8 +29,8 @@
   os <- object.size(x)
   iec <- c("B", "KiB", "MiB", "GiB", "TiB", "PiB", "EiB", "ZiB", "YiB")
   l <- trunc(log(os)/log(1024L))
-  i <- pmin(l+1, 9)
+  i <- pmin(l+1L, 9L)
 
-  return(paste(round(os/(1024^l), digits=3L), iec[i]))
+  return(paste(round(os/(1024L^l), digits=3L), iec[i]))
 }
 
